@@ -3,6 +3,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <errno.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -54,18 +55,34 @@ int audiobufsize = AUDIOBUFSIZE;
 
 static int decode_header(struct frame *fr,unsigned long newhead);
 
+static struct vbrHeader head;
+static int vbr = 0;
+
+void safewrite(int fd, const void *buf, size_t count) {
+       int donesofar = 0;
+       while(donesofar < count) {
+               int retval;
+               retval = write(fd,(buf+donesofar),(count-donesofar));
+               if(retval == -1) {
+                       if((errno != EINTR) && (errno != EAGAIN))
+                               exit(fprintf(stderr,"exception on output!\n"));
+               } else
+                       donesofar += retval;
+       }
+}
+
 void audio_flush(int outmode, struct audio_info_struct *ai)
 {
     if (pcm_point) {
 	switch (outmode) {
 	case DECODE_FILE:
-	    write (OutputDescriptor, pcm_sample, pcm_point);
+	    safewrite (OutputDescriptor, pcm_sample, pcm_point);
 	    break;
 	case DECODE_AUDIO:
 	    audio_play_samples (ai, pcm_sample, pcm_point);
 	    break;
 	case DECODE_BUFFER:
-	    write (buffer_fd[1], pcm_sample, pcm_point);
+	    safewrite (buffer_fd[1], pcm_sample, pcm_point);
 	    break;
 	case DECODE_WAV:
 	case DECODE_CDR:
@@ -448,8 +465,9 @@ int read_frame(struct reader *rds,struct frame *fr)
     }
  
  
-    if(!fr->bitrate_index)
+    if(!fr->bitrate_index) { 
        fr->framesize = fr->freeformatsize + fr->padsize;
+    }
 
 /*
 fprintf(stderr,"Reading %d\n",fr->framesize);
@@ -467,14 +485,9 @@ fprintf(stderr,"Reading %d\n",fr->framesize);
     if(!rds->read_frame_body(rds,bsbuf,fr->framesize))
 	return 0;
 
-    { 
-      /* Test */
-      static struct vbrHeader head;
-      static int vbr = 0; /* FIXME */
-      if(!vbr) {
-        getVBRHeader(&head,bsbuf,fr);
-        vbr = 1;
-      }
+    /* Test */
+    if(!vbr) {
+        vbr = getVBRHeader(&head,bsbuf,fr);
     }
 
     bsi.bitindex = 0;
@@ -605,8 +618,17 @@ void print_header(struct frame *fr)
 	    fr->stereo,fr->copyright?"Yes":"No",
 	    fr->original?"Yes":"No",fr->error_protection?"Yes":"No",
 	    fr->emphasis);
+#if 0
     fprintf(stderr,"Bitrate: %d Kbits/s, Extension value: %d\n",
 	    tabsel_123[fr->lsf][fr->lay-1][fr->bitrate_index],fr->extension);
+#endif
+    fprintf(stderr,"%sBitrate: %d Kbits/s, Extension value: %d\n",
+	    vbr ? "Average " : "",
+	    vbr ? 
+	    (int) (head.bytes * 8 / (compute_tpf(fr) * head.frames * 1000)):
+	    (tabsel_123[fr->lsf][fr->lay-1][fr->bitrate_index]),
+	    fr->extension);
+
 }
 
 void print_header_compact(struct frame *fr)
@@ -742,6 +764,10 @@ double compute_bpf(struct frame *fr)
 {
     double bpf;
 
+    if(!fr->bitrate_index) {
+	return fr->freeformatsize + 4;
+    }
+
     switch(fr->lay) {
     case 1:
 	bpf = tabsel_123[fr->lsf][0][fr->bitrate_index];
@@ -827,7 +853,8 @@ void print_stat(struct reader *rds,struct frame *fr,int no,long buffsize,struct
     }
 #endif
 
-    bpf = compute_bpf(fr);
+    /* bpf = compute_bpf(fr); */
+    bpf = vbr ? (rds->filelen / head.frames) : compute_bpf(fr);
     tpf = compute_tpf(fr);
 
     if(buffsize > 0 && ai && ai->rate > 0 && ai->channels > 0) {
@@ -853,13 +880,14 @@ void print_stat(struct reader *rds,struct frame *fr,int no,long buffsize,struct
 #endif
     tim2 = tim2 < 0 ? 0.0 : tim2;
 
-    sprintf(outbuf+strlen(outbuf),"Time: %02u:%02u.%02u [%02u:%02u.%02u], ",
+    sprintf(outbuf+strlen(outbuf),"Time: %02u:%02u.%02u [%02u:%02u.%02u], Bitrate %3u",
 	    (unsigned int)tim1/60,
 	    (unsigned int)tim1%60,
 	    (unsigned int)(tim1*100)%100,
 	    (unsigned int)tim2/60,
 	    (unsigned int)tim2%60,
-	    (unsigned int)(tim2*100)%100);
+	    (unsigned int)(tim2*100)%100,
+	    (unsigned int)tabsel_123[fr->lsf][fr->lay-1][fr->bitrate_index]);
 
     if(param.usebuffer)
 	sprintf(outbuf+strlen(outbuf),"[%8ld] ",(long)buffsize);
